@@ -27,11 +27,11 @@ def main():
     print(f'Target schema has {len(source)} (table_name,column_name)')
 
     result = source[source.apply(not_exists, axis = 1)]
-    print("The following are missing from target schema:")
+    print("The following are not present in target schema:")
     print(result)
     print(f"Target schema has less {len(result)} (table_name,column_name) than source schema")
     result = result.to_html()
-    f = open("/schema-compare/src/schema_compare/report.html","r")
+    f = open("/src/schema_compare/report.html","r")
 
     content = f.read()
 
